==> ZenTaoPMS.max3.1.php7.1.zip: zentaopms/extension/biz/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPqv1g2YJgH0FtlKz2pQSULd/GZb4AdoRPdJigd9j3zFmoYYMitfsr6VE+CYhei+aSg5Xo+UM
fBN2wcZW5nF8cY/nrbTM5VR2bg22ZZk/GCj0xaRvnzlhUBRbqkfmKA1cBCNdKFZWwDRaigL9p6TY
EUj7MltNcXTD0va0S6V8b5lCTkNl+A4nMU3RWoDOPmTWZOFeagQld9G9dFKkaxgSM6hh1y+xGAR0
EXTZIo90nA9SM5d8IaYI8RB/x8PzRZRv9iEw3ty35TUtJr/NohHZGoeE78xJUjqkp06aNGAc/JhX
WKOLDWPGRYWTZwndy5oFiDuoWmAusSX7hKc7pAwhAI3yNrxu4kpQamgT7TZXzJlxOK44t7QXnyWN
MTBkJlRkZZ+AeCD+HBZCLPrUNCsmUxuTUqGfr1lVNbbOHL+z+IIwgfwiCGQQD/kdvfuqo91Bm1du
xwT2FfeYPikgOHFBYDxuYe0Vbn8chb1WwlHvHN9PZhGMjI9ufluDqt6SslGQP4C4IW7zND4e58U9
efQRYsq3FPaE40tkX2kI07wmPy+wj8B0krWqjrW=

==> ZenTaoPMS.max3.4.php7.1.zip: zentaopms/extension/biz/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPoNACA164ucNgtwbW/QPBvHrj95fvTImG7n/0o88ucek8KCUqdEfOLRj/Il/lfzV/XN3KB7o
XCjqXcoGJ5mzovnIqYfONs2K5I0wFS0sPeIGQXGuRjE6DR5WkIwoc7Cz6TFII5dcrBtki/LRUNXI
m5N8VfMoL1+/vXhXDgDrzHMK8fXMxajdGM74V/iNDblNJjNQFzvjWQn5sFAVJh+L3k/eW1frTwQM
CdvwmTXqgF6A8FiRy3MVX31vUJZDZahX5825R9erSEIjsPc/NCv8gH91z1QbeCJrSTxIuUoBMlNT
hQA3qW7t19XE4l3QlTPs9BDzbwblYqUHBAIQpU6cAOfu3ERBdTsauOJs1jnkfUZPOyHidtgFsesh
mlmzbvu0myZ0BCwCJ37MQPuLHTmQn5bBQew0nogYOs81u89WZs2EO6TWXF2VOFyIAl4i+nCR7D5U
3Q/OqZRmcfnUZUZKRTMQMHfNBylcMfcnTKsIduvvSbibnPQnh7hJI6AdS7NTb4miN6wB6GdKrpjW
T57t1HU0e5O5TDfrr0o76I4frnlj1YfVXm2qFJD/bW==
